# *******************************************************************************
# OpenStudio(R), Copyright (c) Alliance for Sustainable Energy, LLC.
# See also https://openstudio.net/license
# *******************************************************************************

# insert your copyright here

require 'openstudio'
require 'openstudio/measure/ShowRunnerOutput'
require 'minitest/autorun'
require_relative '../measure'
require 'fileutils'

class AddEMPDMaterialPropertiesTest < Minitest::Test
  # def setup
  # end

  # def teardown
  # end

  # def test_number_of_arguments_and_argument_names
  # end

  # def test_bad_argument_values
  # end

  def test_good_argument_values
    # create an instance of the measure
    measure = AddEMPDMaterialProperties.new

    # create runner with empty OSW
    osw = OpenStudio::WorkflowJSON.new
    runner = OpenStudio::Measure::OSRunner.new(osw)

    # load the test model
    translator = OpenStudio::OSVersion::VersionTranslator.new
    path = "#{File.dirname(__FILE__)}/example_model.osm"
    model = translator.loadModel(path)
    assert(!model.empty?)
    model = model.get

    # store the number of spaces in the seed model
    # num_spaces_seed = model.getSpaces.size

    # get arguments
    arguments = measure.arguments(model)
    argument_map = OpenStudio::Measure.convertOSArgumentVectorToMap(arguments)

    # create hash of argument values.
    # If the argument has a default that you want to use, you don't need it in the hash
    args_hash = {}
    args_hash['selected_material'] = '1/2IN Gypsum'
    args_hash['water_diff_fact'] = 6.0
    args_hash['coef_a'] = 0.0068
    args_hash['coef_b'] = 0.939
    args_hash['coef_c'] = 0.0202
    args_hash['coef_d'] = 12.2
    args_hash['surface_penetration'] = '0.019'
    args_hash['deep_penetration'] = '0.073'
    args_hash['coating'] = 0.001
    args_hash['coating_res'] = 200.0
    args_hash['algorithm'] = 'MoisturePenetrationDepthConductionTransferFunction'
    # using defaults values from measure.rb for other arguments

    # populate argument with specified hash value if specified
    arguments.each do |arg|
      temp_arg_var = arg.clone
      if args_hash.key?(arg.name)
        assert(temp_arg_var.setValue(args_hash[arg.name]))
      end
      argument_map[arg.name] = temp_arg_var
    end

    # run the measure
    measure.run(model, runner, argument_map)
    result = runner.result

    # show the output
    show_output(result)

    # assert that it ran correctly
    assert_equal('Success', result.value.valueName)
    assert(result.info.size == 3)
    assert(result.warnings.empty?)

    # check that there is now 1 material with moisture settings
    assert_equal(true, model.getMaterialPropertyMoisturePenetrationDepthSettingss.size == 1)

    # save the model to test output directory
    output_file_path = "#{File.dirname(__FILE__)}//output/test_output.osm"
    model.save(output_file_path, true)
  end
end
